@@ -316,6 +316,7 @@ class Extractor:
                      "document_department_without_tail": None,
                      "year": None,
                      "number": None,
+                     "number_with_tail": None,
                      "special": None}
         org_name = None
         year = None
@@ -344,6 +345,7 @@ class Extractor:
             final_res["document_no_full"] += res.group(0)
             year = res.group(1)
             number = res.group(2)
+            final_res["number_with_tail"] = number + res.group(3)
         else:
             res = re.search('[〔\[\(［]\s*([0-9]{4})\s*[〕\]\)］]\s*([0-9]+)', query)
             if res:
@@ -355,6 +357,7 @@ class Extractor:
                 if res:
                     final_res["document_no_full"] += res.group(0)
                     number = res.group(1)
+                    final_res["number_with_tail"] = number + res.group(2)
                 else:
                     res = re.search('[（\(]([0-9]{6})[\)）]', query)
                     if res:
@@ -369,6 +372,8 @@ class Extractor:
         final_res["year"] = year
         final_res["number"] = number
         final_res["special"] = another_number
+        if not final_res["number_with_tail"]:
+            final_res["number_with_tail"] = number
         return final_res
 
 
@@ -432,7 +437,7 @@ class Extractor:
 """
 if __name__ == '__main__':
     et = Extractor()
-    res = et.extract_reference_no("中国银行业监督管理委员会上海监管局行政处罚决定书（201401）")
+    res = et.extract_reference_no("中国证券监督管理委员会公告〔2021〕33号")
     print(res)
     print(datetime.today())
     start = time.time()
